package VMOMI::CannotPowerOffVmInClusterOperation;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
